function [alpha,kcond,fourier_f,reconst]=fourier(x,y,X_i)
% Fourier approximation (1D case)
% [alpha,kcond,fourier_f,reconst]=fourier(x,y,X_i)
% INPUT
%        x - input data
%        y - output data
%      X_i - harmonic frequency (centers)
% OUTPUT
%      alpha - model scalor factors
%      kcond - kernel conditioning
%  fourier_f - individual sinusoids
%    reconst - reconstructed nonlinearity (sum of all sinusoids)

%  Rev 1.0     Oct. 17, 2003    Dmitriy Shutin <dshutin@inw.tugraz.at>
%  Rev 1.1     Nov. 03, 2009    Daniel Arnitz <daniel.arnitz@tugraz.at>
%                               removed plot and output; returns fourier_f and conditioning instead

% All data should be in columns 
X_i=X_i(:);
x=x(:);
y=y(:);

% Sizes of the vectors
m=size(x,1);
n=size(X_i,1);

% Compute matrices form the datat for 
% matrix-oriented solutions 
MU=ones(m,1)*X_i';
X=x*ones(1,n);

% Compute the basis functions
G = exp( 1j.* X .* MU );
K=G'*G;
kcond=cond(K);

% LS solution for scalor phactors alpha 
epsilon=0;
alpha=inv(K+epsilon*eye(size(K)))*G'*y;

%reconstructed nonlinearity
fourier_f=zeros(m,n);
for k=1:n
    fourier_f(:,k)=alpha(k).* exp( 1j .* x .* X_i(k) );
end
reconst=sum(fourier_f, 2);
