function [alpha,kcond,rbf_f,reconst]=rbf(x,y,X_i,Sigma_i)
% RBF approximation using Gaussian pulses (1D case)
% [alpha,kcond,rbf_f,reconst]=rbf(x,y,X_i,Sigma_i)
% INPUT
%        x - input data
%        y - output data
%      X_i - a column-vector of RBF centers
%  Sigma_i - widths of the corresponding RBFs 
% OUTPUT
%    alpha - model scalor factors
%    kcond - kernel conditioning
%    rbf_f - individual RBFs
%  reconst - reconstructed nonlinearity (sum of all RBFs)

%  Rev 1.0     Oct. 16, 2003    Dmitriy Shutin <dshutin@inw.tugraz.at>  
%  Rev 1.1     Nov. 03, 2009    Daniel Arnitz <daniel.arnitz@tugraz.at>
%                               removed plot and output; returns rbf_f and conditioning instead

% All data should be in columns 
X_i=X_i(:);
Sigma_i=Sigma_i(:);
x=x(:);
y=y(:);

% Sizes of the vectors
m=size(x,1);
n=size(X_i,1);

% Compute matrices form the datat for 
% matrix-oriented solutions 
MU=ones(m,1)*X_i';
SIGMA=ones(m,1)*Sigma_i';
X=x*ones(1,n);

% Compute the exponent of an RBF
G = exp( -0.5 * ( (X-MU).^2 ) ./ (SIGMA.^2) );
K = G'*G;
kcond = cond(K);

% LS solution for scalor phactors alpha
epsilon=0;
alpha=inv(K+epsilon*eye(size(K)))*G'*y;

% reconstructed nonlinearity
rbf_f=zeros(m,n);
for k=1:n
    rbf_f(:,k)=alpha(k)*exp( -0.5*(x-X_i(k)).^2 ./ Sigma_i(k).^2 );
end
reconst=sum(rbf_f, 2);




