function [alpha,kcond,sig_f,reconst]=sigmoid(x,y,X_i,Sigma_i)
% Sigmoid approximation (1D case)
% [alpha,kcond,sig_f,reconst]=sigmoid(x,y,X_i,Sigma_i)
% INPUT
%        x - input data
%        y - output data
%      X_i - a column-vector of sigmoid centers
%  Sigma_i - slope of the sigmoid basis functions 
% OUTPUT
%    alpha - model scalor factors
%    kcond - kernel conditioning
%    sig_f - individual sigmoids
%  reconst - reconstructed nonlinearity (sum of all sigmoids)

%  Rev 1.0     Oct. 17, 2003    Dmitriy Shutin <dshutin@inw.tugraz.at>  
%  Rev 1.1     Nov. 03, 2009    Daniel Arnitz <daniel.arnitz@tugraz.at>
%                               removed plot and output; returns sig_f and conditioning instead

% All data should be in columns 
X_i=X_i(:);
Sigma_i=Sigma_i(:);
x=x(:);
y=y(:);

% Sizes of the vectors
m=size(x,1);
n=size(X_i,1);

% Compute matrices form the datat for 
% matrix-oriented solutions 
MU=ones(m,1)*X_i';
SIGMA=ones(m,1)*Sigma_i';
X=x*ones(1,n);

% Compute the sigmoid basis
G = 1 ./ (1 + exp( - SIGMA .* (X-MU) ) );
K=G'*G;
kcond=cond(K);

% LS solution for scalor phactors alpha 
epsilon=0;
alpha=inv(K+epsilon*eye(size(K)))*G'*y;

%reconstructed nonlinearity
sig_f=zeros(m,n);
for k=1:n
    sig_f(:,k)=alpha(k)./(1 + exp( -Sigma_i(k).*(x-X_i(k)) ) );
end
reconst=sum(sig_f, 2);





